package com.ruoyi.web.work.controller;

import java.util.Arrays;
import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.web.work.domain.ResumeDeliver;
import com.ruoyi.web.work.service.IResumeDeliverService;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 简历投递
 * @author lsw
 * @date 2024-06-13
 */
@RestController
@RequestMapping("/work/deliver")
public class ResumeDeliverController extends BaseController {
    @Autowired
    private IResumeDeliverService resumeDeliverService;

    @PreAuthorize("@ss.hasPermi('work:deliver:list')")
    @GetMapping("/list")
    public TableDataInfo list(ResumeDeliver resumeDeliver){
        startPage();
        List<ResumeDeliver> list = resumeDeliverService.selectList(resumeDeliver);
        return getDataTable(list);
    }

    @PreAuthorize("@ss.hasPermi('work:deliver:query')")
    @GetMapping(value = "/detail/{id}")
    public AjaxResult detail(@PathVariable("id") String id){
        return AjaxResult.success(resumeDeliverService.getById(id));
    }

    @PreAuthorize("@ss.hasPermi('work:deliver:add')")
    @Log(title = "简历投递", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    public AjaxResult add(@RequestBody ResumeDeliver resumeDeliver){
        return toAjax(resumeDeliverService.save(resumeDeliver));
    }

    @PreAuthorize("@ss.hasPermi('work:deliver:edit')")
    @Log(title = "简历投递", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody ResumeDeliver resumeDeliver){
        return toAjax(resumeDeliverService.updateById(resumeDeliver));
    }

    @PreAuthorize("@ss.hasPermi('work:deliver:remove')")
    @Log(title = "简历投递", businessType = BusinessType.DELETE)
    @GetMapping("/remove/{ids}")
    public AjaxResult remove(@PathVariable String[] ids){
        return toAjax(resumeDeliverService.removeByIds(Arrays.asList(ids)));
    }
}
