package com.ruoyi.web.work.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.web.work.api.util.AppUtil;
import com.ruoyi.web.work.domain.Position;
import com.ruoyi.web.work.domain.Resume;
import com.ruoyi.web.work.domain.ResumeDeliver;
import com.ruoyi.web.work.domain.dto.ResumeDeliverDto;
import com.ruoyi.web.work.domain.vo.ReceiveListVo;
import com.ruoyi.web.work.domain.vo.ReceiveVo;
import com.ruoyi.web.work.mapper.ResumeDeliverMapper;
import com.ruoyi.web.work.service.IPositionService;
import com.ruoyi.web.work.service.IResumeDeliverService;
import com.ruoyi.web.work.service.IResumeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @author lsw
 * @date 2024-06-13
 */
@Service
public class ResumeDeliverServiceImpl extends ServiceImpl<ResumeDeliverMapper, ResumeDeliver> implements IResumeDeliverService {
    @Autowired
    private ResumeDeliverMapper resumeDeliverMapper;

    @Autowired
    private IPositionService positionService;

    @Autowired
    private IResumeService resumeService;

    @Override
    public List<ResumeDeliver> selectList(ResumeDeliver resumeDeliver) {
        return resumeDeliverMapper.selectList(resumeDeliver);
    }

    @Override
    public AjaxResult send(Long id) {
        Position position = positionService.getById(id);
        if (position == null || position.getState() != 0 || position.getAudit() != 1) {
            return AjaxResult.error("该职位不存在或已下架");
        }
        Resume resume = resumeService.getById(AppUtil.getUser().getId());
        if (StringUtils.isEmpty(resume.getName()) || StringUtils.isEmpty(resume.getAvatar())) {
            return AjaxResult.error(7979,"请先完善简历再投递");
        }
        ResumeDeliver resumeDeliver = resumeDeliverMapper.check(position.getId(), AppUtil.getUser().getId());
        if (resumeDeliver != null) {
            return AjaxResult.error("请勿重复投递简历");
        }
        resumeDeliver = new ResumeDeliver();
        resumeDeliver.setUserId(AppUtil.getUser().getId());
        resumeDeliver.setType(position.getType());
        resumeDeliver.setPositionId(position.getId());
        resumeDeliver.setEnterpriseId(position.getUserId());
        if (!save(resumeDeliver)) {
            throw new ServiceException("投递简历失败");
        }
        return AjaxResult.success();
    }

    @Override
    public AjaxResult agree(ResumeDeliverDto dto) {
        ResumeDeliver resumeDeliver = getById(dto.getId());
        if (resumeDeliver == null || !resumeDeliver.getUserId().equals(AppUtil.getUser().getId())) {
            return AjaxResult.error("面试不存在或非法操作");
        }
        resumeDeliver.setIsAccept(dto.getIsAccept());
        if (!updateById(resumeDeliver)) {
            throw new ServiceException("接受或拒绝面试邀请失败");
        }
        return AjaxResult.success();
    }

    @Override
    public AjaxResult invite(Long id) {
        ResumeDeliver resumeDeliver = getById(id);
        if (resumeDeliver == null || !resumeDeliver.getEnterpriseId().equals(AppUtil.getUser().getId())) {
            return AjaxResult.error("简历不存在或非法操作");
        }
        if (resumeDeliver.getIsAccept() == 2) {
            return AjaxResult.error("求职者已拒绝，无法重复发送");
        }
        if (resumeDeliver.getIsAccept() == 1) {
            return AjaxResult.error("求职者已同意，请及时安排线下面试");
        }
        if (resumeDeliver.getState() == 1) {
            return AjaxResult.error("已发送邀请，等待求职者同意");
        }
        resumeDeliver.setState(1);
        if (!updateById(resumeDeliver)) {
            throw new ServiceException("发生面试邀请失败");
        }
        return AjaxResult.success();
    }

    @Override
    public AjaxResult detail(Long id) {
        ResumeDeliver resumeDeliver = getById(id);
        if (resumeDeliver == null || !resumeDeliver.getEnterpriseId().equals(AppUtil.getUser().getId())) {
            return AjaxResult.error("简历不存在或非法操作");
        }
        if (resumeDeliver.getIsRead() == 0) {
            resumeDeliver.setIsRead(1);
            updateById(resumeDeliver);
        }
        Resume resume = resumeService.getById(resumeDeliver.getUserId());
        return AjaxResult.success(resume);
    }

    @Override
    public AjaxResult remove(Long id) {
        ResumeDeliver resumeDeliver = getById(id);
        if (resumeDeliver == null || !resumeDeliver.getUserId().equals(AppUtil.getUser().getId())) {
            return AjaxResult.error("简历不存在或非法操作");
        }
        if (!removeById(id)) {
            throw new ServiceException("删除投递失败");
        }
        return AjaxResult.success();
    }

    @Override
    public List<ReceiveVo> receive(Long userId) {
        return resumeDeliverMapper.receive(userId);
    }

    @Override
    public List<ReceiveListVo> receiveList(ResumeDeliver resumeDeliver) {
        return resumeDeliverMapper.receiveList(resumeDeliver);
    }
}
